/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.problems.internal;

import org.gradle.api.NonNullApi;
import org.gradle.api.problems.ProblemLocation;

import javax.annotation.Nullable;

@NonNullApi
public class DefaultProblemLocation implements ProblemLocation {

    private final String path;

    @Nullable
    private final Integer line;

    @Nullable
    private final Integer column;

    public DefaultProblemLocation(String path, @Nullable Integer line, @Nullable Integer column) {
        this.path = path;
        this.line = line;
        this.column = column;
    }

    @Override
    public String getPath() {
        return path;
    }

    @Override
    @Nullable
    public Integer getLine() {
        return line;
    }

    @Override
    @Nullable
    public Integer getColumn() {
        return column;
    }

}
